Crate kcr_app_terraform_io

Crate kcr_app_terraform_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the app.terraform.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

app.terraform.io/v1alpha2

  • AgentPool
  • Module
  • Workspace

Modules

v1alpha2